@@ -2,8 +2,7 @@
 from __future__ import annotations
 
 import re
-from enum import Enum
-from typing import Dict, List, NamedTuple, Optional
+from typing import List, Optional
 
 import inject
 import structlog
@@ -14,9 +13,14 @@ from db_contrib_tool.config import SETUP_REPRO_ENV_CONFIG_FILE, DownloadTarget,
 from db_contrib_tool.services.evergreen_service import EvergreenService
 from db_contrib_tool.services.git_service import GitService
 from db_contrib_tool.services.platform_service import PlatformService
+from db_contrib_tool.setup_repro_env.request_models import (
+    BRANCH_FALLBACK,
+    EvgURLInfo,
+    RequestTarget,
+    RequestType,
+)
 
 LOGGER = structlog.get_logger(__name__)
-BRANCH_FALLBACK = "master"
 NON_VERSION_PROJECTS = {"mongodb-mongo-master", "mongodb-mongo-master-nightly"}
 PROJECT_PREFIX = "mongodb-mongo-"
 VERSION_PROJECT_RE = re.compile(r"mongodb-mongo-v(\d+\.\d+)")
@@ -28,66 +32,6 @@ class MissingBuildVariantError(Exception):
     pass
 
 
-class EvgURLInfo(NamedTuple):
-    """Wrapper around compile URLs with metadata."""
-
-    urls: Dict[str, str]
-    evg_version_id: str
-    project_identifier: str
-
-
-class RequestType(Enum):
-    """
-    How the mongo binaries are being requested.
-
-    * git_commit: Get binaries from a specific commit.
-    * git_branch: Get binaries from a specific git branch.
-    * evg_version: Get binaries from a specific evergreen version.
-    * evg_task: Get binaries from a specific evergreen task.
-    * mongo_release_version: Get binaries for a release version of mongo (e.g. 4.4, 5.0, etc).
-    * mongo_patch_version: Get binaries for a patch version of mongo (e.g. 4.2.18, 6.0.0-rc4, 6.1.0-alpha, etc).
-    """
-
-    GIT_COMMIT = "git_commit"
-    GIT_BRANCH = "git_branch"
-    EVG_VERSION = "evg_version"
-    EVG_TASK = "evg_task"
-    MONGO_RELEASE_VERSION = "mongo_release_version"
-    MONGO_PATCH_VERSION = "mongo_patch_version"
-
-    def __str__(self) -> str:
-        """Display item as a string."""
-        return self.value
-
-
-class RequestTarget(NamedTuple):
-    """
-    Version of mongo binaries that was requested.
-
-    * request_type: Type of the identifier.
-    * identifier: Identifier used to find request.
-    """
-
-    request_type: RequestType
-    identifier: str
-
-    @classmethod
-    def previous_release(cls, identifier: str) -> RequestTarget:
-        """
-        Build a target for either the previous LTS or Continuous release.
-
-        :param identifier: Identifier of release to download.
-        :return: Request target to download given release.
-        """
-        if identifier == BRANCH_FALLBACK:
-            return cls(request_type=RequestType.GIT_BRANCH, identifier=identifier)
-        return cls(request_type=RequestType.MONGO_RELEASE_VERSION, identifier=identifier)
-
-    def __str__(self) -> str:
-        """Display item as a string."""
-        return f"{self.request_type}({self.identifier})"
-
-
 class TaskDependencyParser:
     """Parse dependencies for a given task."""
 
